Package: DFIT
Title: Differential Functioning of Items and Tests
Version: 1.1
Date: 2021-08-16
Author: Victor H. Cervantes <vhcervantesb@unal.edu.co>
Maintainer: Victor H. Cervantes <vhcervantesb@unal.edu.co>
Imports: msm, mirt, simex, mvtnorm, ggplot2
Description: A set of functions to perform Raju, van der Linden and Fleer's
    (1995, <doi:10.1177/014662169501900405>) Differential Functioning of Items
    and Tests (DFIT) analyses. It includes functions to use the Monte Carlo Item
    Parameter Replication approach (Oshima, Raju, & Nanda, 2006, <doi:10.1111/j.1745-3984.2006.00001.x>)
    for obtaining the associated statistical significance
    tests cut-off points. They may also be used for a priori and post-hoc power
    calculations (Cervantes, 2017, <doi:10.18637/jss.v076.i05>).
License: GPL (>= 2)
LazyData: true
NeedsCompilation: no
Encoding: UTF-8
RoxygenNote: 7.1.1
Packaged: 2021-08-17 01:44:15 UTC; herulor
Repository: CRAN
Date/Publication: 2021-08-17 05:20:02 UTC
Built: R 4.6.0; ; 2026-04-29 15:29:49 UTC; unix
